@@ -1,11 +1,15 @@
-{-# LANGUAGE FlexibleContexts, ForeignFunctionInterface, MagicHash,
+{-# LANGUAGE CPP, FlexibleContexts, ForeignFunctionInterface, MagicHash,
              Rank2Types, UnliftedFFITypes #-}
 
 module Data.BloomFilter.Array (newArray) where
 
 import Control.Monad.ST (ST, unsafeIOToST)
 import Data.Array.Base (MArray, STUArray(..), unsafeNewArray_)
+#if __GLASGOW_HASKELL__ >= 704
+import Foreign.C.Types (CInt(..), CSize(..))
+#else
 import Foreign.C.Types (CInt, CSize)
+#endif
 import Foreign.Ptr (Ptr)
 import GHC.Base (MutableByteArray#)
 
